==> kubernetes-model-1.0.64-sources.jar: annotations/io/fabric8/kubernetes/api/model/NodeDaemonEndpointsFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import javax.annotation.Generated;
import io.fabric8.kubernetes.api.builder.Fluent;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.String;
import java.lang.Integer;
import javax.validation.Valid;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import lombok.ToString;
import java.util.Map;
import io.sundr.builder.annotations.Buildable;

public interface NodeDaemonEndpointsFluent<A extends NodeDaemonEndpointsFluent<A>> extends Fluent<A>{


    public DaemonEndpoint getKubeletEndpoint();
    public A withKubeletEndpoint(DaemonEndpoint kubeletEndpoint);
    public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> withNewKubeletEndpoint();
    public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> withNewKubeletEndpointLike(DaemonEndpoint item);
    public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editKubeletEndpoint();
    public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editOrNewKubeletEndpoint();
    public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editOrNewKubeletEndpointLike(DaemonEndpoint item);
    public A withNewKubeletEndpoint(Integer port);

    public interface KubeletEndpointNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DaemonEndpointFluent<NodeDaemonEndpointsFluent.KubeletEndpointNested<N>>{

        
    public N and();    public N endKubeletEndpoint();
}


}

==> kubernetes-model-2.0.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/NodeDaemonEndpointsFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface NodeDaemonEndpointsFluent<A extends NodeDaemonEndpointsFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildKubeletEndpoint instead.
 */
@Deprecated public DaemonEndpoint getKubeletEndpoint();
    public DaemonEndpoint buildKubeletEndpoint();
    public A withKubeletEndpoint(DaemonEndpoint kubeletEndpoint);
    public Boolean hasKubeletEndpoint();
    public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> withNewKubeletEndpoint();
    public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> withNewKubeletEndpointLike(DaemonEndpoint item);
    public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editKubeletEndpoint();
    public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editOrNewKubeletEndpoint();
    public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editOrNewKubeletEndpointLike(DaemonEndpoint item);
    public A withNewKubeletEndpoint(Integer port);

    public interface KubeletEndpointNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DaemonEndpointFluent<NodeDaemonEndpointsFluent.KubeletEndpointNested<N>>{

        
    public N and();    public N endKubeletEndpoint();
}


}
